@@ -15,21 +15,18 @@ from django.urls import reverse
 from django.utils.timezone import make_aware, now, utc
 from django.views.decorators.http import require_POST
 
-from network.base.db_api import DBConnectionError, get_tle_set_by_norad_id, \
-    get_tle_sets, get_transmitter_by_uuid, get_transmitters_by_norad_id, \
-    get_transmitters_by_status
+from network.base.db_api import DBConnectionError, get_tle_set_by_norad_id, get_tle_sets, \
+    get_transmitter_by_uuid, get_transmitters_by_norad_id, get_transmitters_by_status
 from network.base.decorators import ajax_required
 from network.base.forms import ObservationFormSet, SatelliteFilterForm
 from network.base.models import Observation, Satellite, Station
 from network.base.perms import schedule_perms
-from network.base.scheduling import create_new_observation, \
-    get_available_stations, predict_available_observation_windows
+from network.base.scheduling import create_new_observation, get_available_stations, \
+    predict_available_observation_windows
 from network.base.serializers import StationSerializer
-from network.base.stats import satellite_stats_by_transmitter_list, \
-    transmitters_with_stats
+from network.base.stats import satellite_stats_by_transmitter_list, transmitters_with_stats
 from network.base.validators import NegativeElevationError, NoTleSetError, \
-    ObservationOverlapError, SinglePassError, \
-    is_transmitter_in_station_range
+    ObservationOverlapError, SinglePassError, is_transmitter_in_station_range
 
 
 def create_new_observations(formset, user):
@@ -391,10 +388,14 @@ def scheduling_stations(request):
 @require_POST
 def transmitters_view(request):
     """Returns a transmitter JSON object with information and statistics"""
-    norad_id = request.POST['satellite']
+    norad_id = request.POST.get('satellite', None)
     station_id = request.POST.get('station_id', None)
     try:
-        Satellite.objects.get(norad_cat_id=norad_id)
+        if norad_id:
+            Satellite.objects.get(norad_cat_id=norad_id)
+        else:
+            data = {'error': 'Satellite not provided.'}
+            return JsonResponse(data, safe=False)
     except Satellite.DoesNotExist:
         data = {'error': 'Unable to find that satellite.'}
         return JsonResponse(data, safe=False)
